@@ -17,4 +17,5 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__all__ = ['handlers', 'protocols', 'GopherExceptions', 'gopherentry']
+__all__ = ['handlers', 'protocols', 'GopherExceptions', 'gopherentry',
+           'logger']
