@@ -1,10 +1,10 @@
 from pygopherd import protocols, handlers, gopherentry
 from pygopherd.handlers.base import BaseHandler
-from pygopherd.handlers.vfolder import VirtualFolder
+from pygopherd.handlers.virtual import Virtual
 from stat import *
 import imp, re
 
-class PYGHandler(VirtualFolder):
+class PYGHandler(Virtual):
     def canhandlerequest(self):
         if not (self.statresult and S_ISREG(self.statresult[ST_MODE]) and \
                (S_IMODE(self.statresult[ST_MODE]) & S_IXOTH) and \
@@ -16,7 +16,8 @@ class PYGHandler(VirtualFolder):
                                       self.getfspath(),
                                       ('', '', imp.PY_SOURCE))
         self.pygclass = self.module.PYGMain
-        self.pygobject = self.pygclass(self.selector, self.protocol,
+        self.pygobject = self.pygclass(self.selector, self.searchrequest,
+                                       self.protocol,
                                        self.config, self.statresult)
         return self.pygobject.canhandlerequest()
         
@@ -29,7 +30,7 @@ class PYGHandler(VirtualFolder):
     def write(self, wfile):
         self.pygobject.write(wfile)
 
-class PYGBase(VirtualFolder):
+class PYGBase(Virtual):
     pass
 
         
